==> jc-1.4.0.tar.gz: soot/dava/toolkits/base/finders/SequenceFinder.h <==
// public class soot.dava.toolkits.base.finders.SequenceFinder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2a81ad425571cb5e soot_dava_toolkits_base_finders_SequenceFinder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_toolkits_base_finders_SequenceFinder_H_
#define _JC_soot_dava_toolkits_base_finders_SequenceFinder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashSet$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_dava_DavaBody$object;
struct _jc_soot_dava_internal_SET_SETNode$object;
struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object;
struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$object;
struct _jc_soot_util_IterableSet$object;

// Typedefs
typedef struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$sub_refs	_jc_soot_dava_toolkits_base_finders_SequenceFinder$sub_refs;
typedef struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$sub_nonrefs	_jc_soot_dava_toolkits_base_finders_SequenceFinder$sub_nonrefs;
typedef struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$refs	_jc_soot_dava_toolkits_base_finders_SequenceFinder$refs;
typedef struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$nonrefs	_jc_soot_dava_toolkits_base_finders_SequenceFinder$nonrefs;
typedef struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$object	_jc_soot_dava_toolkits_base_finders_SequenceFinder$object;

typedef const struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$vmethods	_jc_soot_dava_toolkits_base_finders_SequenceFinder$vmethods;
typedef const struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$vtable	_jc_soot_dava_toolkits_base_finders_SequenceFinder$vtable;
typedef const struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$vtype	_jc_soot_dava_toolkits_base_finders_SequenceFinder$vtype;

// Constructors
extern void _jc_soot_dava_toolkits_base_finders_SequenceFinder$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_dava_toolkits_base_finders_SequenceFinder$method$find$6aba89b6167e2073(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$object *, struct _jc_soot_dava_DavaBody$object *, struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object *, struct _jc_soot_dava_internal_SET_SETNode$object *);
extern void _jc_soot_dava_toolkits_base_finders_SequenceFinder$method$find__5fStatementSequences$74b9a8fc81e6b6a9(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$object *, struct _jc_soot_dava_internal_SET_SETNode$object *, struct _jc_soot_util_IterableSet$object *, struct _jc_java_util_HashSet$object *, struct _jc_soot_dava_DavaBody$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_toolkits_base_finders_SequenceFinder$method_info$find$6aba89b6167e2073;
extern _jc_method _jc_soot_dava_toolkits_base_finders_SequenceFinder$method_info$find__5fStatementSequences$74b9a8fc81e6b6a9;

// Static methods
extern struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$object *_jc_soot_dava_toolkits_base_finders_SequenceFinder$method$v$5b1fd6d543e0bd12(_jc_env *);

// Virtual methods structure
struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$vmethods {
	void	(*find$6aba89b6167e2073)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$object *, struct _jc_soot_dava_DavaBody$object *, struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object *, struct _jc_soot_dava_internal_SET_SETNode$object *);
	void	(*find__5fStatementSequences$74b9a8fc81e6b6a9)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$object *, struct _jc_soot_dava_internal_SET_SETNode$object *, struct _jc_soot_util_IterableSet$object *, struct _jc_java_util_HashSet$object *, struct _jc_soot_dava_DavaBody$object *);
};

// Vtable
struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_toolkits_base_finders_SequenceFinder$vmethods	soot_dava_toolkits_base_finders_SequenceFinder;
};

// Vtype
struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$vtype {
	_jc_type			type;
	_jc_soot_dava_toolkits_base_finders_SequenceFinder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$refs {
    _jc_soot_dava_toolkits_base_finders_SequenceFinder$sub_refs	soot_dava_toolkits_base_finders_SequenceFinder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_toolkits_base_finders_SequenceFinder$sub_nonrefs	soot_dava_toolkits_base_finders_SequenceFinder;
};

// Object instance structure
struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$object {
	_jc_soot_dava_toolkits_base_finders_SequenceFinder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_toolkits_base_finders_SequenceFinder$vtype	*vtype;
	_jc_soot_dava_toolkits_base_finders_SequenceFinder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_toolkits_base_finders_SequenceFinder$vtype _jc_soot_dava_toolkits_base_finders_SequenceFinder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_toolkits_base_finders_SequenceFinder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_toolkits_base_finders_SequenceFinder$class_object;

#endif	/* _JC_soot_dava_toolkits_base_finders_SequenceFinder_H_ */

==> jc-1.4.6.tar.gz: soot/dava/toolkits/base/finders/SequenceFinder.h <==
// public class soot.dava.toolkits.base.finders.SequenceFinder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2a81ad425571cb5e soot_dava_toolkits_base_finders_SequenceFinder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_toolkits_base_finders_SequenceFinder_H_
#define _JC_soot_dava_toolkits_base_finders_SequenceFinder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashSet$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_dava_DavaBody$object;
struct _jc_soot_dava_internal_SET_SETNode$object;
struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object;
struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$object;
struct _jc_soot_util_IterableSet$object;

// Typedefs
typedef struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$sub_refs	_jc_soot_dava_toolkits_base_finders_SequenceFinder$sub_refs;
typedef struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$sub_nonrefs	_jc_soot_dava_toolkits_base_finders_SequenceFinder$sub_nonrefs;
typedef struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$refs	_jc_soot_dava_toolkits_base_finders_SequenceFinder$refs;
typedef struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$nonrefs	_jc_soot_dava_toolkits_base_finders_SequenceFinder$nonrefs;
typedef struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$object	_jc_soot_dava_toolkits_base_finders_SequenceFinder$object;

typedef const struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$vmethods	_jc_soot_dava_toolkits_base_finders_SequenceFinder$vmethods;
typedef const struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$vtable	_jc_soot_dava_toolkits_base_finders_SequenceFinder$vtable;
typedef const struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$vtype	_jc_soot_dava_toolkits_base_finders_SequenceFinder$vtype;

// Constructors
extern void _jc_soot_dava_toolkits_base_finders_SequenceFinder$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_dava_toolkits_base_finders_SequenceFinder$method$find$6aba89b6167e2073(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$object *, struct _jc_soot_dava_DavaBody$object *, struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object *, struct _jc_soot_dava_internal_SET_SETNode$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_toolkits_base_finders_SequenceFinder$method$find__5fStatementSequences$74b9a8fc81e6b6a9(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$object *, struct _jc_soot_dava_internal_SET_SETNode$object *, struct _jc_soot_util_IterableSet$object *, struct _jc_java_util_HashSet$object *, struct _jc_soot_dava_DavaBody$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_toolkits_base_finders_SequenceFinder$method_info$find$6aba89b6167e2073;
extern _jc_method _jc_soot_dava_toolkits_base_finders_SequenceFinder$method_info$find__5fStatementSequences$74b9a8fc81e6b6a9;

// Static methods
extern struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$object *_jc_soot_dava_toolkits_base_finders_SequenceFinder$method$v$5b1fd6d543e0bd12(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$vmethods {
	void	(*find$6aba89b6167e2073)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$object *, struct _jc_soot_dava_DavaBody$object *, struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object *, struct _jc_soot_dava_internal_SET_SETNode$object *) _JC_JCNI_ATTR;
	void	(*find__5fStatementSequences$74b9a8fc81e6b6a9)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$object *, struct _jc_soot_dava_internal_SET_SETNode$object *, struct _jc_soot_util_IterableSet$object *, struct _jc_java_util_HashSet$object *, struct _jc_soot_dava_DavaBody$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_toolkits_base_finders_SequenceFinder$vmethods	soot_dava_toolkits_base_finders_SequenceFinder;
};

// Vtype
struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$vtype {
	_jc_type			type;
	_jc_soot_dava_toolkits_base_finders_SequenceFinder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$refs {
    _jc_soot_dava_toolkits_base_finders_SequenceFinder$sub_refs	soot_dava_toolkits_base_finders_SequenceFinder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_toolkits_base_finders_SequenceFinder$sub_nonrefs	soot_dava_toolkits_base_finders_SequenceFinder;
};

// Object instance structure
struct _jc_soot_dava_toolkits_base_finders_SequenceFinder$object {
	_jc_soot_dava_toolkits_base_finders_SequenceFinder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_toolkits_base_finders_SequenceFinder$vtype	*vtype;
	_jc_soot_dava_toolkits_base_finders_SequenceFinder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_toolkits_base_finders_SequenceFinder$vtype _jc_soot_dava_toolkits_base_finders_SequenceFinder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_toolkits_base_finders_SequenceFinder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_toolkits_base_finders_SequenceFinder$class_object;

#endif	/* _JC_soot_dava_toolkits_base_finders_SequenceFinder_H_ */
